<?php

namespace Litecms\Lead\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Lead\Models\Lead;


class LeadAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Lead $lead, array $request = [])
    {
        $this->model = $lead;

        $function = Str::camel($action);
        event('litecms.lead.lead.action.' . $action . 'ing', [$lead]);
        $data =  $this->$function($lead, $request);
        event('litecms.lead.lead.action.' . $action . 'ed', [$lead]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Lead $lead, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $lead = $lead->create($attributes);
        return $lead;
    }

    public function update(Lead $lead, array $request)
    {
        $attributes = $request;
        $lead->update($attributes);
        return $lead;
    }

    public function destroy(Lead $lead, array $request)
    {
        $lead->delete();
        return $lead;
    }

    public function copy(Lead $lead, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $lead = $lead->replicate();
            $lead->created_at = Carbon::now();
            $lead->save();
            return $lead;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $lead->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $lead;
    }


}
