<?php

namespace Litecms\Lead\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Lead\Actions\LeadAction;
use Litecms\Lead\Http\Requests\LeadActionRequest;
use Litecms\Lead\Http\Resources\LeadResource;
use Litecms\Lead\Models\Lead;

/**
 * Admin web controller class.
 */
class LeadActionController extends BaseController
{

    /**
     * Action controller function for lead.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LeadActionRequest $request, Lead $lead, $action)
    {
        try {
            $lead = LeadAction::run($request, $lead, $action);

            $data = new LeadResource($lead);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('lead::lead.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('lead/lead/' . $lead->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lead/lead/' . $lead->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
