<?php

namespace Litecms\Lead\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Lead\Http\Resources\LeadResource;
use Litecms\Lead\Http\Resources\LeadsCollection;
use Litecms\Lead\Scopes\LeadPublicScope;
use Litecms\Lead\Models\Lead;

class LeadPublicController extends BaseController
{

    /**
     * Show lead's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Lead::pushScope(new RequestScope())
            ->pushScope(new LeadPublicScope())
            ->select('leads.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new LeadsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('lead::lead.names'))
            ->view('lead::public.lead.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show lead.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Lead::findBySlug($slug);
        $data = new LeadResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('lead::lead.name'))
            ->view('lead::public.lead.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
