<?php

namespace Litecms\Lead\Http\Controllers;

use Exception;
use Litecms\Lead\Actions\LeadWorkflow;
use Litecms\Lead\Http\Requests\LeadWorkflowRequest;
use Litecms\Lead\Http\Resources\LeadResource;
use Litecms\Lead\Models\Lead;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class LeadWorkflowController extends BaseController
{
    /**
     * Action controller function for lead.
     *
     * @param Model $lead
     * @param action next action for the lead.
     *
     * @return Response
     */
    public function __invoke(LeadWorkflowRequest $request, Lead $lead, $trasition)
    {
        try {
            $lead = LeadWorkflow::run($request, $lead, $trasition);
            $data = new LeadResource($lead);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('lead::lead.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('lead/lead/' . $lead->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lead/lead/' . $lead->getRouteKey()))
                ->redirect();
        }
    }
}
