<?php

namespace Litecms\Lead\Http\Controllers;

use Exception;
use Litecms\Lead\Actions\UserWorkflow;
use Litecms\Lead\Http\Requests\UserWorkflowRequest;
use Litecms\Lead\Http\Resources\UserResource;
use Litecms\Lead\Models\User;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class UserWorkflowController extends BaseController
{
    /**
     * Action controller function for user.
     *
     * @param Model $user
     * @param action next action for the user.
     *
     * @return Response
     */
    public function __invoke(UserWorkflowRequest $request, User $user, $trasition)
    {
        try {
            $user = UserWorkflow::run($request, $user, $trasition);
            $data = new UserResource($user);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('lead::user.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('lead/user/' . $user->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lead/user/' . $user->getRouteKey()))
                ->redirect();
        }
    }
}
