<?php
namespace Litecms\Lead\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Lead\Events\LeadAction as LeadActionEvent;
use Litecms\Lead\Models\Lead;

class LeadAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $lead;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param LeadActionEvent $lead
     * @param string $action
     */
    public function __construct(LeadActionEvent $lead, string $action)
    {
        $this->action = $action;
        $this->lead = $lead;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Lead Approved - ' . config('app.name'))
            ->view('lead::lead.email.action', ['data' => $this->lead]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
