<?php
namespace Litecms\Lead\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Lead\Events\UserAction as UserActionEvent;
use Litecms\Lead\Models\User;

class UserAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $user;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param UserActionEvent $user
     * @param string $action
     */
    public function __construct(UserActionEvent $user, string $action)
    {
        $this->action = $action;
        $this->user = $user;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('User Approved - ' . config('app.name'))
            ->view('lead::user.email.action', ['data' => $this->user]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
