<?php

namespace Litecms\Lead\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Lead\Models\Lead;

class LeadPolicy
{

    use LeadAction;
    use LeadExim;
    use LeadWorkflow;

    /**
     * Determine if the given user can view the lead.
     *
     * @param UserPolicyInterface $authUser
     * @param Lead $lead
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Lead $lead)
    {
        if ($authUser->canDo('lead.lead.view') && $authUser->isAdmin()) {
            return true;
        }

        return $lead->user_id == user_id() && $lead->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lead.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('lead.lead.create');
    }

    /**
     * Determine if the given user can update the given lead.
     *
     * @param UserPolicyInterface $authUser
     * @param Lead $lead
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Lead $lead)
    {
        if ($authUser->canDo('lead.lead.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $lead->user_id == user_id() && $lead->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lead.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Lead $lead)
    {
        return $lead->user_id == user_id() && $lead->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lead.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Lead $lead)
    {
        if ($authUser->canDo('lead.lead.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lead.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Lead $lead)
    {
        if ($authUser->canDo('lead.lead.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
